Learn R Programming

hyperSpec (version 0.99-20201127)

.fileio.optional: Helper function to harmonize treatment of file import results

Description

This function provides two ways of post-processing imported spectra:

Usage

.fileio.optional(
  spc,
  filename,
  ...,
  file.remove.emptyspc = hy.getOption("file.remove.emptyspc"),
  file.keep.name = hy.getOption("file.keep.name"),
  tolerance = hy.getOption("tolerance")
)

Arguments

spc

hyperSpec object for file import post-processing

filename

filename(s) to become extra data column of `spc`

...

(ignored)

file.remove.emptyspc

should empty (all `NA` or all `0`) spectra be removed?

file.keep.name

should file names be kept and put into `spc$filename`?

tolerance

intensities in +/- `tolerance` are considered `0` for `file.remove.emptyspc = TRUE`

Value

hyperSpec object

Details

- optionally remove empty spectra (some spectrograph software will produce empty spectra when measurements are cancelled) - optionally keep the filenames in column `spc$filename`

The desired overall behavior can be set by options via [hy.setOptions()]. All file import filters should call `.fileio.optional()` to ensure the same behavior.