Learn R Programming

hyperSpec (version 0.99-20201127)

hy.unittest: hyperSpec unit tests

Description

If testthat is available, run the unit tests and display the results.

Usage

hy.unittest(standalone = TRUE, reporter = "progress")

Arguments

standalone

run the unit test on their own, e.g. from the console (`TRUE`) or within testthat tests (`FALSE`), e.g. via `devtools::test()`

reporter

the reporter to use, defaults to [testthat::ProgressReporter]

Value

Invisibly returns a data frame with the test results

Examples

Run this code
# NOT RUN {
hy.unittest ()

# }

Run the code above in your browser using DataLab