Learn R Programming

hyperSpec (version 0.98-20150304)

read.txt.Horiba: Import Horiba Labspec exported ASCII files

Description

Read ASCII (.txt) files exported by Horiba's Labspec software (LabRAM spectrometers)

read.txt.Horiba.t reads time series, i.e. .txt files with the time in the first column

Usage

read.txt.Horiba(file, cols = c(spc = "I / a.u.", .wavelength = expression(Delta * tilde(nu)/cm^-1)), header = TRUE, sep = "\t", row.names = NULL, check.names = FALSE, ..., remove.zerospc = TRUE)
read.txt.Horiba.xy(file, ...)
read.txt.Horiba.t(file, header = TRUE, sep = "\t", row.names = NULL, check.names = FALSE, ..., remove.zerospc = TRUE)

Arguments

file
connection (file name and path) to the .txt file
cols,header,sep,row.names,check.names,...
further parameters are handed over to read.txt.wide
remove.zerospc
LabRAM saves spectra consisting of zeros only if e.g. a map was aborted. The default is to remove these spectra.

Value

hyperSpec object

Details

read.txt.Horiba.xy reads maps, i.e. .txt files where the first two columns give x and y coordinates.