vector giving the numer of cases to generate for each group
mean
matrix with mean cases in rows
sigma
common covariance matrix or array (ncol (mean) x ncol (mean) x nrow (mean)) with individual covariance matrices for the groups.
Details
The mvtnorm method for hyperSpec objects supports producing multivariate normal data for
groups with different mean but common covariance matrix, see the examples.