Learn R Programming

hyperSpec (version 0.99-20201127)

wc: line/word/character count of ASCII files

Description

`wc()` uses the system command `wc`. Use at your own risk.

Usage

wc(file, flags = c("lines", "words", "bytes"))

Arguments

file

the file name or pattern

flags

the parameters to count, character vector with the long form of the parameters

Value

data.frame with the counts and file names, or `NULL` if wc is not available on the system.

See Also

[count_lines()]