Learn R Programming

hyperSpec (version 0.100.3)

.fix_spc_colnames: Ensure that the spectra matrix has the wavelengths in column names

Description

Ensure that the spectra matrix has the wavelengths in column names

Usage

.fix_spc_colnames(spc)

Value

hyperSpec object with wavelengths in column names of $spc

Arguments

spc

hyperSpec object