powered by
If testthat is available, run the unit tests and display the results.
testthat
hy.unittest(standalone = TRUE, reporter = "progress")
run the unit test on their own, e.g. from the console (`TRUE`) or within testthat tests (`FALSE`), e.g. via `devtools::test()`
the reporter to use, defaults to [testthat::ProgressReporter]
Invisibly returns a data frame with the test results
# NOT RUN { hy.unittest () # }
Run the code above in your browser using DataLab