read.txt.Horiba.t reads time series, i.e. .txt files with the time in the first column
read.txt.Horiba(file, cols = c(spc = "I / a.u.", .wavelength = expression(Delta * tilde(nu)/cm^-1)), header = TRUE, sep = "\t", row.names = NULL, check.names = FALSE, ..., remove.zerospc = TRUE)
read.txt.Horiba.xy(file, ...)
read.txt.Horiba.t(file, header = TRUE, sep = "\t", row.names = NULL, check.names = FALSE, ..., remove.zerospc = TRUE)read.txt.wideread.txt.Horiba.xy reads maps, i.e. .txt files where the first two columns give x and y coordinates.