gzfile (i.e. text, or zipped by gzip, bzip2, xz or
lzma). .zip zipped files need to be read using scan.zip.Renishaw.
scan.txt.Renishaw(file = stop("file is required"), data = "xyspc", nlines = 0, nspc = NULL)
scan.zip.Renishaw(file = stop("filename is required"), txt.file = sub("[.]zip", ".txt", basename(file)), ...)nlines must cover at least one complete spectrum,i.e. nlines
must be at least the number of data points per spectrum. Reasonable
values start at 1e6.
scan.txt.RenishawhyperSpec object
The corresponding possibilities for the data argument are:
data |
columns |
"spc" |
|
| wl int | single spectrum |
"zspc", "depth" |
z wl int |
| depth profile | "ts" |
| t wl int | time series |
"xyspc" |
y x wl int |
| 2d map | data |
This function allows reading very large ASCII files, but it does not work
on files with missing values (NAs are allowed).
If the file is so large that it sould be read in chunks and nspc is
not given, scan.txt.Renishaw tries to guess it by using wc
(if installed).
read.txt.long, read.txt.wide,
scan